import { Kind } from 'graphql';
import { klona } from 'klona';

function modifyQueryForChain(chainName, originalDocumentNode) {
    // We need to deep clone the document node in order to not mutate the query so it is consistent
    // across multiple calls to the same query with different chains
    const documentNode = klona(originalDocumentNode);
    documentNode.definitions = documentNode.definitions.map((doc) => {
        if (doc.kind === Kind.OPERATION_DEFINITION) {
            doc.selectionSet.selections = doc.selectionSet.selections.map((selection) => {
                if (selection.kind === Kind.FIELD &&
                    selection.name.kind == Kind.NAME &&
                    selection.name.value === 'ethereum') {
                    const updatedChainSelection = {
                        ...selection,
                        name: { ...selection.name, value: chainName },
                    };
                    return updatedChainSelection;
                }
                return selection;
            });
        }
        return doc;
    });
    return documentNode;
}

export { modifyQueryForChain };
